@@ -22,10 +22,12 @@ import collections
 import hashlib
 import time
 
-from pyipmi.errors import DecodingError, CompletionCodeError, HpmError, TimeoutError
+from pyipmi.errors import CompletionCodeError, HpmError, TimeoutError
 from pyipmi.msgs import create_request_by_name
 from pyipmi.msgs import constants
 from pyipmi.utils import check_completion_code, bcd_search, chunks
+from pyipmi.state import State
+from pyipmi.fields import VersionField
 
 
 PROPERTY_GENERAL_PROPERTIES = 0
@@ -40,7 +42,7 @@ ACTION_PREPARE_COMPONENT = 0x01
 ACTION_UPLOAD_FOR_UPGRADE = 0x02
 ACTION_UPLOAD_FOR_COMPARE = 0x03
 
-LONG_DURATION_CMD_IN_PROGRESS_CC = 0x80
+CC_LONG_DURATION_CMD_IN_PROGRESS = 0x80
 
 CC_GET_COMP_PROP_UPGRADE_NOT_SUPPORTED_OVER_INTF = 0x81
 CC_GET_COMP_PROP_INVALID_COMPONENT = 0x82
@@ -57,19 +59,14 @@ CC_QUERY_SELFTEST_NO_RESULTS_AVAILABLE = 0xD5
 CC_ABORT_UPGRADE_CANNOT_ABORT = 0x80
 CC_ABORT_UPGRADE_CANNOT_RESUME_OPERATION = 0x81
 
-class Hpm:
-
-    def _check_completion_code(self, rsp):
-        check_completion_code(rsp.completion_code)
+class Hpm(object):
 
     def _get_component_count(self, components):
         """Return the number of components"""
         return bin(components).count('1')
 
     def get_target_upgrade_capabilities(self):
-        req = create_request_by_name('GetTargetUpgradeCapabilities')
-        rsp = self.send_message(req)
-        self._check_completion_code(rsp)
+        rsp = self.send_message_with_name('GetTargetUpgradeCapabilities')
         return TargetUpgradeCapabilities(rsp)
 
     def get_component_property(self, component_id, property_id):
@@ -77,17 +74,21 @@ class Hpm:
         req.id = component_id
         req.selector = property_id
         rsp = self.send_message(req)
-        self._check_completion_code(rsp)
-        return ComponentProperty.create_from_id(property_id, rsp)
+        check_completion_code(rsp.completion_code)
+        return ComponentProperty.from_data(property_id, rsp.data)
 
     def get_component_properties(self, component_id):
         properties = []
         for p in (PROPERTY_GENERAL_PROPERTIES, PROPERTY_CURRENT_VERSION,
                 PROPERTY_DESCRIPTION_STRING, PROPERTY_ROLLBACK_VERSION,
                 PROPERTY_DEFERRED_VERSION):
-            property = self.get_component_property(component_id, p)
-            if property is not None:
-                properties.append(property)
+            try:
+                property = self.get_component_property(component_id, p)
+                if property is not None:
+                    properties.append(property)
+            except CompletionCodeError, e:
+                if e.cc == CC_GET_COMP_PROP_INVALID_PROPERTIES_SELECTOR:
+                    continue
         return properties
 
     def find_component_id_by_descriptor(self, descriptor):
@@ -100,9 +101,7 @@ class Hpm:
         return None
 
     def abort_firmware_upgrade(self):
-        req = create_request_by_name('AbortFirmwareUpgrade')
-        rsp = self.send_message(req)
-        self._check_completion_code(rsp)
+        self.send_message_with_name('AbortFirmwareUpgrade')
 
     def initiate_upgrade_action(self, components_mask, action):
         """ Initiate Upgrade Action
@@ -132,7 +131,7 @@ class Hpm:
         try:
             self.initiate_upgrade_action(components_mask, action)
         except CompletionCodeError, e:
-            if e.cc == LONG_DURATION_CMD_IN_PROGRESS_CC:
+            if e.cc == CC_LONG_DURATION_CMD_IN_PROGRESS:
                 self.wait_for_long_duration_command(
                         constants.CMDID_HPM_INITIATE_UPGRADE_ACTION,
                         timeout, interval)
@@ -160,7 +159,7 @@ class Hpm:
             try:
                 self.upload_firmware_block(block_number, chunk)
             except CompletionCodeError, e:
-                if e.cc == LONG_DURATION_CMD_IN_PROGRESS_CC:
+                if e.cc == CC_LONG_DURATION_CMD_IN_PROGRESS:
                     self.wait_for_long_duration_command(
                             constants.CMDID_HPM_UPLOAD_FIRMWARE_BLOCK,
                             timeout, interval)
@@ -184,7 +183,7 @@ class Hpm:
             rsp = self.finish_firmware_upload(component, length)
             check_completion_code(rsp.completion_code)
         except CompletionCodeError, e:
-            if e.cc == LONG_DURATION_CMD_IN_PROGRESS_CC:
+            if e.cc == CC_LONG_DURATION_CMD_IN_PROGRESS:
                 self.wait_for_long_duration_command(
                             constants.CMDID_HPM_FINISH_FIRMWARE_UPLOAD,
                             timeout, interval)
@@ -192,13 +191,9 @@ class Hpm:
                 raise HpmError('finish_firmware_upload CC=0x%02x' % e.cc)
 
     def get_upgrade_status(self):
-        req = create_request_by_name('GetUpgradeStatus')
-        rsp = self.send_message(req)
-        self._check_completion_code(rsp)
-        return UpgradeStatus(rsp)
+        return UpgradeStatus(self.send_message_with_name('GetUpgradeStatus'))
 
-    def wait_for_long_duration_command(self, expected_cmd,
-            timeout=5, interval=1):
+    def wait_for_long_duration_command(self, expected_cmd, timeout, interval):
 
         start_time = time.time()
         while time.time() < start_time + timeout:
@@ -206,10 +201,8 @@ class Hpm:
                 status = self.get_upgrade_status()
                 if status.command_in_progress is not expected_cmd \
                         and status.command_in_progress is not 0x34:
-                    #raise HpmError('unexpected cmd=0x%02x' \
-                    #        % status.command_in_progress)
                     pass
-                if status.last_completion_code == LONG_DURATION_CMD_IN_PROGRESS_CC:
+                if status.last_completion_code == CC_LONG_DURATION_CMD_IN_PROGRESS:
                     time.sleep(interval)
                 else:
                     return
@@ -222,7 +215,7 @@ class Hpm:
         if rollback_override != None:
             req.rollback_override_policy = rollback_override
         rsp = self.send_message(req)
-        self._check_completion_code(rsp)
+        check_completion_code(rsp.completion_code)
 
     def activate_firmware_and_wait(self, rollback_override=None,
             timeout=2, interval=1):
@@ -231,7 +224,7 @@ class Hpm:
         try:
             self.activate_firmware(rollback_override)
         except CompletionCodeError, e:
-            if e.cc == LONG_DURATION_CMD_IN_PROGRESS_CC:
+            if e.cc == CC_LONG_DURATION_CMD_IN_PROGRESS:
                 self.wait_for_long_duration_command(
                             constants.CMDID_HPM_ACTIVATE_FIRMWARE,
                             timeout, interval)
@@ -242,28 +235,19 @@ class Hpm:
             pass
 
     def query_selftest_results(self):
-        req = create_request_by_name('QuerySelftestResults')
-        rsp = self.send_message(req)
-        self._check_completion_code(rsp)
-        return SelfTestResult(rsp.data)
+        return SelfTestResult(self.send_message_with_name('QuerySelftestResults'))
 
     def query_rollback_status(self):
-        req = create_request_by_name('QueryRollbackStatus')
-        rsp = self.send_message(req)
-        self._check_completion_code(rsp)
-        return RollbackStatus(rsp)
+        return RollbackStatus(self.send_message_with_name('QueryRollbackStatus'))
 
     def initiate_manual_rollback(self):
-        req = create_request_by_name('InitiateManualRollback')
-        rsp = self.send_message(req)
-        self._check_completion_code(rsp)
-        return RollbackStatus(rsp)
+        return RollbackStatus(self.send_message_with_name('InitiateManualRollback'))
 
     def initiate_maunal_rollback_and_wait(self, timeout=2, interval=0.1):
         try:
             self.initiate_manual_rollback()
         except CompletionCodeError, e:
-            if e.cc == LONG_DURATION_CMD_IN_PROGRESS_CC:
+            if e.cc == CC_LONG_DURATION_CMD_IN_PROGRESS:
                 self.wait_for_long_duration_command(
                             constants.CMDID_HPM_INITIATE_MANUAL_ROLLBACK,
                             60, interval)
@@ -280,23 +264,23 @@ class Hpm:
     def get_upgrade_version_from_file(self, filename):
         image = UpgradeImage(filename)
         for action in image.actions:
-            if action.type == ACTION_UPLOAD_FOR_UPGRADE:
+            if type(action) == UpgradeActionRecordUploadForUpgrade:
                 return action.firmware_version
         return None
 
     def _do_upgrade_action_backup(self, image):
         for action in image.actions:
-            if action.type == ACTION_BACKUP_COMPONENT:
+            if type(action) == UpgradeActionRecordBackup:
                 pass
 
     def _do_upgrade_action_prepare(self, image):
         for action in image.actions:
-            if action.type == ACTION_PREPARE_COMPONENT:
+            if type(action) == UpgradeActionRecordPrepare:
                 print "do ACTION_PREPARE_COMPONENT"
 
     def _do_upgrade_action_upload(self, image):
         for action in image.actions:
-            if action.type == ACTION_UPLOAD_FOR_UPGRADE:
+            if type(action) == UpgradeActionRecordUploadForUpgrade:
                 print "do ACTION_UPLOAD_FOR_UPGRADE"
 
 
@@ -337,8 +321,8 @@ class Hpm:
         for action in image.actions:
             if action.components & (1 << component) == 0:
                 continue
-            self.initiate_upgrade_action_and_wait(1 << component, action.type)
-            if action.type == ACTION_UPLOAD_FOR_UPGRADE:
+            self.initiate_upgrade_action_and_wait(1 << component, action.action_type)
+            if type(action) == UpgradeActionRecordUploadForUpgrade:
                 self.upload_binary(action.firmware_image_data)
                 self.finish_upload_and_wait(component, action.firmware_length)
 
@@ -373,10 +357,7 @@ class Hpm:
         self.install_component_from_image(image, component)
 
 
-class UpgradeStatus:
-    def __init__(self, rsp=None):
-        if rsp:
-            self._from_response(rsp)
+class UpgradeStatus(State):
 
     def _from_response(self, rsp):
         self.command_in_progress = rsp.command_in_progress
@@ -389,10 +370,7 @@ class UpgradeStatus:
         return "\n".join(str)
 
 
-class TargetUpgradeCapabilities:
-    def __init__(self, rsp=None):
-        if rsp:
-            self._from_response(rsp)
+class TargetUpgradeCapabilities(State):
 
     def _from_response(self, rsp):
         self.version = rsp.hpm_1_version
@@ -403,227 +381,178 @@ class TargetUpgradeCapabilities:
 
     def __str__(self):
         str = []
-        str.append("target upgrade capabilities %s" % self.components)
+        str.append("Target Upgrade Capabilities")
         str.append(" HPM.1 version: %s" % self.version)
+        str.append(" Components: %s" % self.components)
         return "\n".join(str)
 
 
-VERSION_FIELD_LEN = 6
-class VersionField:
-    def __init__(self, data=None):
-        self.major = None
-        self.minor = None
-        if data:
-            self.from_data(data)
-
-    def from_data(self, data):
-        if isinstance(data, str):
-            data = array.array('B', [ord(c) for c in data])
-        self.version = self._decode_version_string(data[0:2])
-        if len(data) == 6:
-            self.auxiliary = data[2:6]
-
-    def __str__(self):
-        str = []
-        str.append('%s' % (self.version_to_string()))
-        return '\n'.join(str)
-
-    def _decode_version_string(self, data):
-        """`data` is array.array
-        """
-        self.major = data[0]
-
-        if data[1] is not 255:
-            self.minor = data[1:2].tostring().decode('bcd+')
-        else:
-            self.minor = data[1]
-
-    def version_to_string(self):
-        return ''.join("%s.%s" % (self.major, self.minor))
-
-
 codecs.register(bcd_search)
 
-class ComponentProperty:
-    def __init__(self, id):
-        self.id = id
+class ComponentProperty(object):
+    def __init__(self, data=None):
+        if (data):
+            self._from_rsp_data(data)
 
     @staticmethod
-    def create_from_id(id, rsp):
-        if id is PROPERTY_GENERAL_PROPERTIES:
-            return ComponentPropertyGeneral(rsp.data)
+    def from_data(component_id, data):
+        if isinstance(data, str):
+            data = [ord(c) for c in data]
 
-        elif id is PROPERTY_CURRENT_VERSION:
-            return ComponentPropertyCurrentVersion(rsp.data)
-
-        elif id is PROPERTY_DESCRIPTION_STRING:
-            return ComponentPropertyDescriptionString(rsp.data)
-
-        elif id is PROPERTY_ROLLBACK_VERSION:
-            return ComponentPropertyRollbackVersion(rsp.data)
-
-        elif id is PROPERTY_DEFERRED_VERSION:
-            return ComponentPropertyDeferredVersion(rsp.data)
-
-        elif id in PROPERTY_OEM:
+        if component_id is PROPERTY_GENERAL_PROPERTIES:
+            return ComponentPropertyGeneral(data)
+        elif component_id is PROPERTY_CURRENT_VERSION:
+            return ComponentPropertyCurrentVersion(data)
+        elif component_id is PROPERTY_DESCRIPTION_STRING:
+            return ComponentPropertyDescriptionString(data)
+        elif component_id is PROPERTY_ROLLBACK_VERSION:
+            return ComponentPropertyRollbackVersion(data)
+        elif component_id is PROPERTY_DEFERRED_VERSION:
+            return ComponentPropertyDeferredVersion(data)
+        elif component_id in PROPERTY_OEM:
             raise NotImplementedError
 
 
 class ComponentPropertyGeneral(ComponentProperty):
-    def __init__(self, data=None):
-        ComponentProperty.__init__(self, PROPERTY_GENERAL_PROPERTIES)
-        if (data):
-            self._from_data(data)
 
-    def _from_data(self, data):
-        ROLLBACK_SUPPORT_MASK = 0x03
-        PREPARATION_SUPPORT_MASK = 0x04
-        COMPARISON_SUPPORT_MASK = 0x08
-        DEFERRED_ACTIVATION_SUPPORT_MASK = 0x10
-        PAYLOAD_COLD_RESET_REQ_SUPPORT_MASK = 0x20
+    ROLLBACK_SUPPORT_MASK = 0x03
+    PREPARATION_SUPPORT_MASK = 0x04
+    COMPARISON_SUPPORT_MASK = 0x08
+    DEFERRED_ACTIVATION_SUPPORT_MASK = 0x10
+    PAYLOAD_COLD_RESET_REQ_SUPPORT_MASK = 0x20
+
+    def _from_rsp_data(self, data):
         support = []
         cap = data[0]
-        if cap & ROLLBACK_SUPPORT_MASK == 0:
+
+        if cap & self.ROLLBACK_SUPPORT_MASK == 0:
             support.append('rollback_backup_not_supported')
-        elif cap & ROLLBACK_SUPPORT_MASK == 1:
+        elif cap & self.ROLLBACK_SUPPORT_MASK == 1:
             support.append('rollback_is_supported')
-        elif cap & ROLLBACK_SUPPORT_MASK == 2:
+        elif cap & self.ROLLBACK_SUPPORT_MASK == 2:
             support.append('rollback_is_supported')
-        elif cap & ROLLBACK_SUPPORT_MASK == 3:
+        elif cap & self.ROLLBACK_SUPPORT_MASK == 3:
             support.append('reserved')
-        if cap & PREPARATION_SUPPORT_MASK:
+
+        if cap & self.PREPARATION_SUPPORT_MASK:
             support.append('prepartion')
-        if cap & COMPARISON_SUPPORT_MASK:
+        if cap & self.COMPARISON_SUPPORT_MASK:
             support.append('comparison')
-        if cap & DEFERRED_ACTIVATION_SUPPORT_MASK:
+        if cap & self.DEFERRED_ACTIVATION_SUPPORT_MASK:
             support.append('deferred_activation')
-        if cap & PAYLOAD_COLD_RESET_REQ_SUPPORT_MASK:
+        if cap & self.PAYLOAD_COLD_RESET_REQ_SUPPORT_MASK:
             support.append('payload_cold_reset_required')
+
         self.general = support
 
 
 class ComponentPropertyCurrentVersion(ComponentProperty):
-    def __init__(self, data=None):
-        ComponentProperty.__init__(self, PROPERTY_CURRENT_VERSION)
-        if (data):
-            self._from_msg_response(data)
 
-    def _from_msg_response(self, data):
+    def _from_rsp_data(self, data):
         self.version = VersionField(data)
 
 
 class ComponentPropertyDescriptionString(ComponentProperty):
-    def __init__(self, data=None):
-        ComponentProperty.__init__(self, PROPERTY_DESCRIPTION_STRING)
-        if (data):
-            self._from_msg_response(data)
 
-    def _from_msg_response(self, data):
-        descr =  data.tostring().replace('\0', '')
-        self.description = descr
+    def _from_rsp_data(self, data):
+        self.description =  array.array('B', data).tostring().replace('\0', '')
 
 
 class ComponentPropertyRollbackVersion(ComponentProperty):
-    def __init__(self, data=None):
-        ComponentProperty.__init__(self, PROPERTY_ROLLBACK_VERSION)
-        if (data):
-            self._from_msg_response(data)
 
-    def _from_msg_response(self, data):
+    def _from_rsp_data(self, data):
         self.version = VersionField(data)
 
 
 class ComponentPropertyDeferredVersion(ComponentProperty):
-    def __init__(self, data=None):
-        ComponentProperty.__init__(self, PROPERTY_DEFERRED_VERSION)
-        if (data):
-            self._from_msg_response(data)
 
-    def _from_msg_response(self, data):
+    def _from_rsp_data(self, data):
         self.version = VersionField(data)
 
 
 class ComponentPropertyOem(ComponentProperty):
-    def __init__(self, data=None):
-        if (data):
-            self._from_msg_response(data)
 
-    def _from_msg_response(self, data):
-        raise NotImplementedError()
+    def _from_rsp_data(self, data):
+        self.oem_data = data
 
 
-class SelfTestResult:
-    def __init__(self, data=None):
-        if data:
-            self.from_data(data)
+class SelfTestResult(State):
 
-    def from_data(self, data):
-        self.status = data[0]
+    CORRUPTED_OR_INACCESSIBLE_DATA_OR_DEVICES = 0x57
 
-        if self.status  != 0x57:
-            self.fail.sel = (data[1] & 0x80) >> 7
-            self.fail.sdrr = (data[1] & 0x40) >> 6
-            self.fail.bmc_fru = (data[1] & 0x20) >> 5
-            self.fail.ipmb = (data[1] & 0x10) >> 4
-            self.fail.sdrr_empty = (data[1] & 0x08) >> 3
-            self.fail.bmc_fru_interanl_area = (data[1] & 0x04) >> 2
-            self.fail.bootblock = (data[1] & 0x02) >> 1
-            self.fail.mc = (data[1] & 0x01) >> 0
+    def _from_response(self, rsp):
+        self.status = rsp.selftest_result_1
+
+        result2 = rsp.selftest_result_2
+
+        if self.status  != self.CORRUPTED_OR_INACCESSIBLE_DATA_OR_DEVICES:
+            self.fail_sel = (result2 & 0x80) >> 7
+            self.fail_sdrr = (result2 & 0x40) >> 6
+            self.fail_bmc_fru = (result2 & 0x20) >> 5
+            self.fail_ipmb = (result2 & 0x10) >> 4
+        self.fail_sdrr_empty = (result2 & 0x08) >> 3
+        self.fail_bmc_fru_interanl_area = (result2 & 0x04) >> 2
+        self.fail_bootblock = (result2 & 0x02) >> 1
+        self.fail_mc = (result2 & 0x01) >> 0
 
 
-class RollbackStatus:
+class RollbackStatus(object):
     def __init__(self, rsp=None):
         if rsp:
-            self.from_rsp(rsp)
+            self._from_rsp(rsp)
 
-    def from_rsp(self, rsp):
+    def _from_rsp(self, rsp):
 
         if rsp.completion_estimate:
             self.percent_complete  = rsp.completion_estimate
 
 
-ImageHeader = collections.namedtuple('ImageHeader', ['field_name', 'format', 'start', 'len'])
+image_header = collections.namedtuple('image_header', ['field_name', 'format', 'start', 'len'])
 
-class UpgradeImageHeaderRecord:
+class UpgradeImageHeaderRecord(object):
     FORMAT  = [
-        ImageHeader('format_version', 'B', 8, 1),
-        ImageHeader('device_id', 'B', 9, 1),
-        ImageHeader('product_id', '<H', 13, 2),
-        ImageHeader('time', '<L', 15, 4),
-        ImageHeader('capabilities', 'B', 19,1),
-        #ImageHeader('components', 'B',  20, 1),
-        ImageHeader('selftest_timeout', 'B', 21, 1),
-        ImageHeader('rollback_timeout', 'B', 22, 1),
-        ImageHeader('inaccessibility_timeout', 'B', 23, 1),
-        ImageHeader('earliest_compatible_revision', '<H', 24, 2),
-        ImageHeader('oem_data_length', '<H', 32, 2),
+        image_header('format_version', 'B', 8, 1),
+        image_header('device_id', 'B', 9, 1),
+        image_header('product_id', '<H', 13, 2),
+        image_header('time', '<L', 15, 4),
+        image_header('capabilities', 'B', 19,1),
+        image_header('selftest_timeout', 'B', 21, 1),
+        image_header('rollback_timeout', 'B', 22, 1),
+        image_header('inaccessibility_timeout', 'B', 23, 1),
+        image_header('earliest_compatible_revision', '<H', 24, 2),
+        image_header('oem_data_length', '<H', 32, 2),
     ]
 
     def __init__(self, data=None):
         for a in self.FORMAT:
             setattr(self, a.field_name, None)
         if data:
-            self.from_data(data)
+            self._from_data(data)
 
-    def from_data(self, data):
+    def _from_data(self, data):
         self.signature = data[0:8]
 
         for a in self.FORMAT:
-            setattr(self, a.field_name, struct.unpack(a.format, data[a.start:a.start+a.len])[0])
-        self.manufacturer_id = ord(data[10]) | ord(data[11]) << 8|ord(data[12])<<16
+            setattr(self, a.field_name, struct.unpack(
+                    a.format, data[a.start:a.start+a.len])[0])
+
+        if isinstance(data, str):
+            data = [ord(c) for c in data]
+
+        self.manufacturer_id = data[10] | data[11] << 8 | data[12] << 16
         self.components = []
         for i in range(8):
-            if ord(data[20]) & (1<<i):
+            if data[20] & (1 << i):
                 self.components.append(i)
-        self.earliest_compatible_revision = VersionField(data[24:24+2])
-        self.firmware_revision = VersionField(data[26:26+VERSION_FIELD_LEN])
+        self.earliest_compatible_revision = VersionField(data[24:24 +
+        VersionField.VERSION_FIELD_LEN])
+        self.firmware_revision = VersionField(data[26:26 + VersionField.VERSION_WITH_AUX_FIELD_LEN])
 
-
-        if self.oem_data_length != 0:
-            self.oem_data = [ord(d) for d in data[34:-1]]
+        if self.oem_data_length:
+            self.oem_data = data[34:-1]
         # XXX checksum check
-        self.checksum = data[34+self.oem_data_length]
-        self.length = 34+self.oem_data_length+1
+        self.checksum = data[34 + self.oem_data_length]
+        self.length = 34 + self.oem_data_length+1
 
     def __str__(self):
         str = []
@@ -645,7 +574,7 @@ class UpgradeImageHeaderRecord:
         return "\n".join(str)
 
 
-class UpgradeActionRecord:
+class UpgradeActionRecord(object):
 
     ACTIONS = (
         "Backup",
@@ -655,55 +584,48 @@ class UpgradeActionRecord:
     )
 
     def __init__(self, data=None):
+        self.action_type = ord(data[0])
         if data:
-            (self.type, self.components, self.checksum) = struct.unpack('BBB', data[0:3])
-            #self.components = struct.unpack('B', data[1:2])
-            #self.checksum = struct.unpack('B', data[2:3])
+            (self.action, self.components, self.checksum) \
+                = struct.unpack('BBB', data[0:3])
             self.length = 3
 
     @staticmethod
     def create_from_data(data):
-        type = ord(data[0])
-        if type == ACTION_BACKUP_COMPONENT:
+        action_type = ord(data[0])
+        if action_type == ACTION_BACKUP_COMPONENT:
             return UpgradeActionRecordBackup(data)
-        elif type == ACTION_PREPARE_COMPONENT:
+        elif action_type == ACTION_PREPARE_COMPONENT:
             return UpgradeActionRecordPrepare(data)
-        elif type == ACTION_UPLOAD_FOR_UPGRADE:
+        elif action_type == ACTION_UPLOAD_FOR_UPGRADE:
             return UpgradeActionRecordUploadForUpgrade(data)
-        elif type == ACTION_UPLOAD_FOR_COMPARE:
+        elif action_type == ACTION_UPLOAD_FOR_COMPARE:
             return UpgradeActionRecordUploadForCompare(data)
         else:
             raise HpmError('unsupported ActionRecord')
 
     def __str__(self):
         str = []
-        str.append("Action Record Type: 0x%x (%s) " % (self.type, self.ACTIONS[self.type]))
+        str.append("Action Record Type: 0x%x (%s) " %
+            (self.action, self.ACTIONS[self.action]))
         str.append(" Components: 0x%02x" % self.components)
         return "\n".join(str)
 
 
 class UpgradeActionRecordBackup(UpgradeActionRecord):
-    def __init__(self, data=None):
-        if (data):
-            UpgradeActionRecord.__init__(self, data)
+    pass
 
 
 class UpgradeActionRecordPrepare(UpgradeActionRecord):
-    def __init__(self, data=None):
-        if (data):
-            UpgradeActionRecord.__init__(self, data)
+    pass
 
 
 class UpgradeActionRecordUploadForUpgrade(UpgradeActionRecord):
     def __init__(self, data=None):
-        if (data):
-            UpgradeActionRecord.__init__(self, data)
-
-            ###################################################
-            # PICMG HPM.1 R1.0 - Table 4-3
-            #    Upgrade action recordThe following bytes 3:(34+m) are only present
-            #   if the Upgrade action type = 02h (Upload Firmware Image)
-            self.firmware_version = VersionField(data[3:3+VERSION_FIELD_LEN])
+        UpgradeActionRecord.__init__(self, data)
+        if data:
+            self.firmware_version = VersionField(data[3:3 +
+            VersionField.VERSION_WITH_AUX_FIELD_LEN])
             self.firmware_description_string = data[9:30]
             self.firmware_length = struct.unpack('<L', data[30:34])[0]
             self.firmware_image_data = data[34:(34 + self.firmware_length)]
@@ -711,12 +633,10 @@ class UpgradeActionRecordUploadForUpgrade(UpgradeActionRecord):
 
 
 class UpgradeActionRecordUploadForCompare(UpgradeActionRecord):
-    def __init__(self, data=None):
-        if (data):
-            UpgradeActionRecord.__init__(self, data)
+    pass
 
 
-class ImageChecksumRecord:
+class ImageChecksumRecord(object):
     def __init__(self, data=None):
         if data:
             self._from_data(data)
@@ -727,7 +647,7 @@ class ImageChecksumRecord:
 
 HPM_IMAGE_CHECKSUM_SIZE = 16
 
-class UpgradeImage:
+class UpgradeImage(object):
     def __init__(self, filename=None):
         if filename:
             self._from_file(filename)
