@@ -24,6 +24,7 @@ from pyipmi.msgs import create_request_by_name
 from pyipmi.msgs import constants
 
 from pyipmi.helper import get_sdr_data_helper, clear_repository_helper
+from pyipmi.state import State
 
 SDR_TYPE_FULL_SENSOR_RECORD = 0x01
 SDR_TYPE_COMPACT_SENSOR_RECORD = 0x02
@@ -37,27 +38,19 @@ SDR_TYPE_BMC_MESSAGE_CHANNEL_INFO_RECORD = 0x14
 GET_INITIALIZATION_AGENT_STATUS = 0
 RUN_INITIALIZATION_AGENT = 1
 
-class Sdr:
+class Sdr(object):
     def get_sdr_repository_info(self):
-        req = create_request_by_name('GetSdrRepositoryInfo')
-        rsp = self.send_message(req)
-        check_completion_code(rsp.completion_code)
-        return SdrRepositoryInfo(rsp)
+        return SdrRepositoryInfo(self.send_message_with_name('GetSdrRepositoryInfo'))
 
     def get_sdr_repository_allocation_info(self):
-        req = create_request_by_name('GetSdrRepositoryAllocationInfo')
-        rsp = self.send_message(req)
-        check_completion_code(rsp.completion_code)
-        return SdrRepositoryAllocationInfo(rsp)
+        return SdrRepositoryAllocationInfo(
+                self.send_message_with_name('GetSdrRepositoryAllocationInfo'))
 
     def reserve_sdr_repository(self):
-        req = create_request_by_name('ReserveSdrRepository')
-        rsp = self.send_message(req)
-        check_completion_code(rsp.completion_code)
+        rsp = self.send_message_with_name('ReserveSdrRepository')
         return rsp.reservation_id
 
     def _get_sdr_chunk(self, reservation_id, record_id, offset, length):
-        print length
         req = create_request_by_name('GetSdr')
         req.reservation_id = reservation_id
         req.record_id = record_id
@@ -162,12 +155,9 @@ class Sdr:
     def get_initialization_agent_status(self):
         return self._run_initialization_agent(GET_INITIALIZATION_AGENT_STATUS)
 
-class SdrRepositoryInfo:
-    def __init__(self, rsp):
-        if rsp:
-            self.from_response(rsp)
+class SdrRepositoryInfo(State):
 
-    def from_response(self, rsp):
+    def _from_response(self, rsp):
         self.sdr_version = rsp.sdr_version
         self.record_count = rsp.record_count
         self.free_space = rsp.free_space
@@ -179,12 +169,9 @@ class SdrRepositoryInfo:
         self.support_update_type = rsp.support.update_type
         self.support_overflow_flag = rsp.support.overflow_flag
 
-class SdrRepositoryAllocationInfo:
-    def __init__(self, rsp):
-        if rsp:
-            self.from_response(rsp)
+class SdrRepositoryAllocationInfo(State):
 
-    def from_response(self, rsp):
+    def _from_response(self, rsp):
         self.number_of_units = rsp.number_of_units
         self.unit_size = rsp.unit_size
         self.free_units = rsp.free_units
@@ -213,10 +200,10 @@ def create_sdr(data, next_id=None):
         raise DecodingError('Unsupported SDR type(0x%02x)' % sdr_type)
 
 
-class SdrCommon:
-    def __init__(self, rsp=None, next_id=None):
-        if rsp:
-            self.from_response(rsp)
+class SdrCommon(object):
+    def __init__(self, data, next_id=None):
+        if data:
+            self._from_response(data)
         if next_id:
             self.next_id = next_id
 
@@ -225,7 +212,7 @@ class SdrCommon:
             (self.device_id_string, ' '.join(['%02x' % b for b in self.data]))
         return s
 
-    def from_response(self, data):
+    def _from_response(self, data):
         if len(data) < 5:
             raise DecodingError('Invalid SDR length (%d)' % len(data))
 
@@ -234,7 +221,7 @@ class SdrCommon:
         self.id = buffer.pop_unsigned_int(2)
         self.version = buffer.pop_unsigned_int(1)
         self.type = buffer.pop_unsigned_int(1)
-        self.lenght = buffer.pop_unsigned_int(1)
+        self.length = buffer.pop_unsigned_int(1)
 
 ###
 # SDR type 0x01
@@ -261,7 +248,7 @@ class SdrFullSensorRecord(SdrCommon):
     def __init__(self, data, next_id=None):
         SdrCommon.__init__(self, data, next_id)
         if data:
-            self.from_data(data)
+            self._from_data(data)
 
     def convert_sensor_raw_to_value(self, raw):
         fmt = self.analog_data_format
@@ -334,7 +321,7 @@ class SdrFullSensorRecord(SdrCommon):
             value = -(1<<size) + value
         return value
 
-    def from_data(self, data):
+    def _from_data(self, data):
         buffer = ByteBuffer(data[5:])
         # record key bytes
         self.owner_id = buffer.pop_unsigned_int(1)
@@ -490,9 +477,9 @@ class SdrCompactSensorRecord(SdrCommon):
     def __init__(self, data, next_id=None):
         SdrCommon.__init__(self, data, next_id)
         if data:
-            self.from_data(data)
+            self._from_data(data)
 
-    def from_data(self, data):
+    def _from_data(self, data):
         buffer = ByteBuffer(data[5:])
         self.owner_id = buffer.pop_unsigned_int(1)
         self.owner_lun = buffer.pop_unsigned_int(1) & 0x3
@@ -501,7 +488,7 @@ class SdrCompactSensorRecord(SdrCommon):
         self.entity_instance = buffer.pop_unsigned_int(1)
         self.sensor_initialization = buffer.pop_unsigned_int(1)
         self.capabilities = buffer.pop_unsigned_int(1)
-        self.sensor_type = buffer.pop_unsigned_int(1)
+        self.sensor_type_code = buffer.pop_unsigned_int(1)
         self.event_reading_type_code = buffer.pop_unsigned_int(1)
         self.assertion_mask = buffer.pop_unsigned_int(2)
         self.deassertion_mask = buffer.pop_unsigned_int(2)
@@ -525,12 +512,9 @@ class SdrEventOnlySensorRecord(SdrCommon):
     def __init__(self, data, next_id=None):
         SdrCommon.__init__(self, data, next_id)
         if data:
-            self.from_data(data)
+            self._from_data(data)
 
-    def __str__(self):
-        return 'Not supported yet.'
-
-    def from_data(self, data):
+    def _from_data(self, data):
         buffer = ByteBuffer(data[5:])
         self.owner_id = buffer.pop_unsigned_int(1)
         self.owner_lun = buffer.pop_unsigned_int(1) & 0x3
@@ -552,9 +536,9 @@ class SdrFruDeviceLocator(SdrCommon):
     def __init__(self, data, next_id=None):
         SdrCommon.__init__(self, data, next_id)
         if data:
-            self.from_data(data)
+            self._from_data(data)
 
-    def from_data(self, data):
+    def _from_data(self, data):
         buffer = ByteBuffer(data[5:])
         # record key bytes
         self.device_access_address = buffer.pop_unsigned_int(1) >> 1
@@ -579,9 +563,9 @@ class SdrManagementContollerDeviceLocator(SdrCommon):
     def __init__(self, data, next_id=None):
         SdrCommon.__init__(self, data, next_id)
         if data:
-            self.from_data(data)
+            self._from_data(data)
 
-    def from_data(self, data):
+    def _from_data(self, data):
         buffer = ByteBuffer(data[5:])
         self.device_slave_address = buffer.pop_unsigned_int(1) >> 1
         self.channel_number = buffer.pop_unsigned_int(1) & 0xf
