@@ -18,6 +18,7 @@ import codecs
 from array import array
 import pyipmi.msgs.constants
 import pyipmi.errors
+from pyipmi.msgs import create_request_by_name
 
 def check_completion_code(cc):
     if cc != pyipmi.msgs.constants.CC_OK:
@@ -27,7 +28,7 @@ def chunks(d, n):
     for i in xrange(0, len(d), n):
         yield d[i:i+n]
 
-class ByteBuffer:
+class ByteBuffer(object):
     def __init__(self, data=None):
         if data is not None:
             self.array = array('B', data)
